@@ -653,7 +653,11 @@ glade_command_set_property_description (GladeCommandSetProperty * me)
   return description;
 }
 
-
+/**
+ * glade_command_set_properties_list:
+ *
+ * @props (element-type GladeProperty): List of #GladeProperty
+ */
 void
 glade_command_set_properties_list (GladeProject * project, GList * props)
 {
@@ -971,7 +975,12 @@ glade_command_placeholder_connect (CommandData * cdata,
        G_CALLBACK (glade_command_placeholder_destroyed), cdata);
 }
 
-
+/**
+ * get_all_parentless_reffed_widgetst:
+ *
+ * @props (element-type GladeWidget) : List of #GladeWidget
+ * @return (element-type GladeWidget) : List of #GladeWidget
+ */
 static GList *
 get_all_parentless_reffed_widgets (GList * reffed, GladeWidget * widget)
 {
@@ -996,7 +1005,7 @@ get_all_parentless_reffed_widgets (GList * reffed, GladeWidget * widget)
 
 /**
  * glade_command_add:
- * @widgets: a #Glist
+ * @widgets (element-type GladeWidget): a #Glist
  * @parent: a #GladeWidget
  * @placeholder: a #GladePlaceholder
  * @pasting: whether we are pasting an existing widget or creating a new one.
@@ -1171,7 +1180,7 @@ glade_command_remove_locked (GladeWidget * widget, GList * reffed)
 
 /**
  * glade_command_remove:
- * @widgets: a #GList of #GladeWidgets
+ * @widgets (element-type GladeWidget): a #GList of #GladeWidgets
  * @return_placeholders: whether or not to return a list of placehodlers
  *
  * Performs a remove command on all widgets in @widgets from @parent.
@@ -1553,8 +1562,8 @@ glade_command_add_remove_collapse (GladeCommand * this_cmd,
 /**
  * glade_command_create:
  * @adaptor:		A #GladeWidgetAdaptor
- * @parent:             the parent #GladeWidget to add the new widget to.
- * @placeholder:	the placeholder which will be substituted by the widget
+ * @parent (allow-none):             the parent #GladeWidget to add the new widget to.
+ * @placeholder (allow-none):	the placeholder which will be substituted by the widget
  * @project:            the project his widget belongs to.
  *
  * Creates a new widget using @adaptor and put in place of the @placeholder
@@ -1581,6 +1590,13 @@ glade_command_create (GladeWidgetAdaptor * adaptor, GladeWidget * parent,
       return NULL;
     }
 
+  if (parent && !glade_widget_add_verify (parent, widget, TRUE))
+    {
+      g_object_ref_sink (widget);
+      g_object_unref (widget);
+      return NULL;
+    }
+
   widgets = g_list_prepend (widgets, widget);
   glade_command_push_group (_("Create %s"), glade_widget_get_name (widget));
   glade_command_add (widgets, parent, placeholder, project, FALSE);
@@ -1596,7 +1612,7 @@ glade_command_create (GladeWidgetAdaptor * adaptor, GladeWidget * parent,
 
 /**
  * glade_command_delete:
- * @widgets: a #GList of #GladeWidgets
+ * @widgets (element-type GladeWidget): a #GList of #GladeWidgets
  *
  * Performs a delete command on the list of widgets.
  */
@@ -1617,7 +1633,7 @@ glade_command_delete (GList * widgets)
 
 /**
  * glade_command_cut:
- * @widgets: a #GList of #GladeWidgets
+ * @widgets (element-type GladeWidget): a #GList of #GladeWidgets
  *
  * Removes the list of widgets and adds them to the clipboard.
  */
@@ -1707,9 +1723,9 @@ glade_command_break_references (GladeProject * project, GList * widgets)
 
 /**
  * glade_command_paste:
- * @widgets: a #GList of #GladeWidget
- * @parent: a #GladeWidget
- * @placeholder: a #GladePlaceholder
+ * @widgets (element-type GladeWidget): a #GList of #GladeWidget
+ * @parent (allow-none): a #GladeWidget
+ * @placeholder (allow-none): a #GladePlaceholder
  *
  * Performs a paste command on all widgets in @widgets to @parent, possibly
  * replacing @placeholder (note toplevels dont need a parent; the active project
@@ -1749,9 +1765,9 @@ glade_command_paste (GList * widgets, GladeWidget * parent,
 
 /**
  * glade_command_dnd:
- * @widgets: a #GList of #GladeWidget
- * @parent: a #GladeWidget
- * @placeholder: a #GladePlaceholder
+ * @widgets (element-type GladeWidget): a #GList of #GladeWidget
+ * @parent (allow-none): a #GladeWidget
+ * @placeholder (allow-none): a #GladePlaceholder
  *
  * Performs a drag-n-drop command, i.e. removes the list of widgets and adds them 
  * to the new parent, possibly replacing @placeholder (note toplevels dont need a 
@@ -2131,140 +2147,6 @@ glade_command_set_i18n (GladeProperty * property,
     g_object_unref (G_OBJECT (me));
 }
 
-
-/******************************************************************************
- * 
- * set project naming policy 
- * 
- * This command sets the naming policy on the project.
- * 
- *****************************************************************************/
-
-typedef struct
-{
-  GladeCommand parent;
-  GladeNamingPolicy policy;
-  GladeNamingPolicy old_policy;
-} GladeCommandSetPolicy;
-
-
-GLADE_MAKE_COMMAND (GladeCommandSetPolicy, glade_command_set_policy);
-#define GLADE_COMMAND_SET_POLICY_TYPE			(glade_command_set_policy_get_type ())
-#define GLADE_COMMAND_SET_POLICY(o)	  		(G_TYPE_CHECK_INSTANCE_CAST ((o), GLADE_COMMAND_SET_POLICY_TYPE, GladeCommandSetPolicy))
-#define GLADE_COMMAND_SET_POLICY_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST ((k), GLADE_COMMAND_SET_POLICY_TYPE, GladeCommandSetPolicyClass))
-#define GLADE_IS_COMMAND_SET_POLICY(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), GLADE_COMMAND_SET_POLICY_TYPE))
-#define GLADE_IS_COMMAND_SET_POLICY_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GLADE_COMMAND_SET_POLICY_TYPE))
-
-static gboolean
-glade_command_set_policy_execute (GladeCommand * cmd)
-{
-  GladeCommandSetPolicy *me = (GladeCommandSetPolicy *) cmd;
-  GladeNamingPolicy policy;
-
-  /* set the new policy */
-  glade_project_set_naming_policy (cmd->priv->project, me->policy);
-
-  /* swap the current values with the old values to prepare for undo */
-  policy = me->policy;
-  me->policy = me->old_policy;
-  me->old_policy = policy;
-
-  return TRUE;
-}
-
-static gboolean
-glade_command_set_policy_undo (GladeCommand * cmd)
-{
-  return glade_command_set_policy_execute (cmd);
-}
-
-static void
-glade_command_set_policy_finalize (GObject * obj)
-{
-/* 	GladeCommandSetPolicy	*me; */
-
-  g_return_if_fail (GLADE_IS_COMMAND_SET_POLICY (obj));
-
-  glade_command_finalize (obj);
-}
-
-static gboolean
-glade_command_set_policy_unifies (GladeCommand * this_cmd,
-                                  GladeCommand * other_cmd)
-{
-/* 	GladeCommandSetPolicy *cmd1; */
-/* 	GladeCommandSetPolicy *cmd2; */
-
-  return FALSE;
-}
-
-static void
-glade_command_set_policy_collapse (GladeCommand * this_cmd,
-                                   GladeCommand * other_cmd)
-{
-  /* this command is the one that will be used for an undo of the sequence of like commands */
-  //GladeCommandSetPolicy *this = GLADE_COMMAND_SET_POLICY (this_cmd);
-
-  /* the other command contains the values that will be used for a redo */
-  //GladeCommandSetPolicy *other = GLADE_COMMAND_SET_POLICY (other_cmd);
-
-  g_return_if_fail (GLADE_IS_COMMAND_SET_POLICY (this_cmd) &&
-                    GLADE_IS_COMMAND_SET_POLICY (other_cmd));
-
-  /* no unify/collapse */
-}
-
-/**
- * glade_command_set_project_naming_policy:
- * @project: a #GladeProject
- * @policy: the #GladeNamingPolicy
- *
- * Sets the naming policy of a project
- */
-void
-glade_command_set_project_naming_policy (GladeProject * project,
-                                         GladeNamingPolicy policy)
-{
-  GladeCommandSetPolicy *me;
-
-  g_return_if_fail (GLADE_IS_PROJECT (project));
-
-  if (glade_project_get_naming_policy (project) != policy)
-    {
-      gchar *prj_name = glade_project_get_name (project);
-      glade_command_push_group (_("Setting %s to use a %s naming policy"),
-                                prj_name,
-                                policy == GLADE_POLICY_PROJECT_WIDE ?
-                                "project wide" : "toplevel contextual");
-      g_free (prj_name);
-
-      /* load up the command */
-      me = g_object_new (GLADE_COMMAND_SET_POLICY_TYPE, NULL);
-      me->policy = policy;
-      me->old_policy = glade_project_get_naming_policy (project);
-
-      GLADE_COMMAND (me)->priv->project = project;
-      GLADE_COMMAND (me)->priv->description = g_strdup_printf ("dummy string");
-
-      glade_command_check_group (GLADE_COMMAND (me));
-
-      /* execute the command and push it on the stack if successful 
-       * this sets the actual policy
-       */
-      if (glade_command_set_policy_execute (GLADE_COMMAND (me)))
-        {
-          glade_project_push_undo (project, GLADE_COMMAND (me));
-        }
-      else
-        {
-          g_object_unref (G_OBJECT (me));
-        }
-
-      glade_command_pop_group ();
-    }
-}
-
-
 /******************************************************************************
  * 
  * This command sets protection warnings on widgets
