@@ -59,7 +59,8 @@
 enum
 {
   PROP_0,
-  PROP_PROJECT
+  PROP_PROJECT,
+  N_PROPERTIES
 };
 
 enum
@@ -82,7 +83,7 @@ struct _GladeInspectorPrivate
   gboolean search_disabled;
 };
 
-
+static GParamSpec *properties[N_PROPERTIES];
 static guint glade_inspector_signals[LAST_SIGNAL] = { 0 };
 
 
@@ -174,15 +175,15 @@ glade_inspector_class_init (GladeInspectorClass * klass)
                     G_STRUCT_OFFSET (GladeInspectorClass, item_activated),
                     NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
-  g_object_class_install_property (object_class,
-                                   PROP_PROJECT,
-                                   g_param_spec_object ("project",
-                                                        _("Project"),
-                                                        _
-                                                        ("The project being inspected"),
-                                                        GLADE_TYPE_PROJECT,
-                                                        G_PARAM_READABLE |
-                                                        G_PARAM_WRITABLE));
+  properties[PROP_PROJECT] =
+    g_param_spec_object ("project",
+                         _("Project"),
+                         _("The project being inspected"),
+                         GLADE_TYPE_PROJECT,
+                         G_PARAM_READABLE | G_PARAM_WRITABLE);
+  
+  /* Install all properties */
+  g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 
   g_type_class_add_private (klass, sizeof (GladeInspectorPrivate));
 }
@@ -265,12 +266,11 @@ search_complete_idle (GladeInspector * inspector)
   GladeInspectorPrivate *priv = inspector->priv;
   const gchar *str;
   gchar *completed = NULL;
-  GList *list;
   gsize length;
 
   str = gtk_entry_get_text (GTK_ENTRY (priv->entry));
 
-  list = g_completion_complete (priv->completion, str, &completed);
+  g_completion_complete (priv->completion, str, &completed);
   if (completed)
     {
       length = strlen (str);
@@ -493,12 +493,22 @@ glade_inspector_dispose (GObject * object)
 
   glade_inspector_set_project (inspector, NULL);
 
+  if (inspector->priv->idle_complete)
+    {
+      g_source_remove (inspector->priv->idle_complete);
+      inspector->priv->idle_complete = 0;
+    }
+
   G_OBJECT_CLASS (glade_inspector_parent_class)->dispose (object);
 }
 
 static void
 glade_inspector_finalize (GObject * object)
 {
+  GladeInspector *inspector = GLADE_INSPECTOR (object);
+
+  g_completion_free (inspector->priv->completion);
+
   G_OBJECT_CLASS (glade_inspector_parent_class)->finalize (object);
 }
 
@@ -822,7 +832,7 @@ glade_inspector_set_project (GladeInspector * inspector, GladeProject * project)
 
   update_project_completion (project, NULL, inspector);
 
-  g_object_notify (G_OBJECT (inspector), "project");
+  g_object_notify_by_pspec (G_OBJECT (inspector), properties[PROP_PROJECT]);
 }
 
 /**
