@@ -1163,14 +1163,11 @@ glade_property_write (GladeProperty * property,
                       GladeXmlContext * context, GladeXmlNode * node)
 {
   GladeXmlNode *prop_node;
-  GladeProject *project;
-  gchar *name, *value, *tmp;
+  gchar *name, *value;
 
   g_return_if_fail (GLADE_IS_PROPERTY (property));
   g_return_if_fail (node != NULL);
 
-  project = glade_widget_get_project (property->priv->widget);
-
   /* This code should work the same for <packing> and <widget> */
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_PACKING) ||
         glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET)))
@@ -1195,13 +1192,6 @@ glade_property_write (GladeProperty * property,
      * funcs that may not like NULL.
      */
     value = g_strdup ("");
-  else
-    {
-      /* Escape the string so that it will be parsed as it should. */
-      tmp = value;
-      value = g_markup_escape_text (value, -1);
-      g_free (tmp);
-    }
 
   /* Now dump the node values... */
   prop_node = glade_xml_node_new (context, GLADE_XML_TAG_PROPERTY);
