@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 Juan Pablo Ugarte.
  *
- * This library is free software; you can redistribute it and/or it
+ * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
@@ -435,7 +435,12 @@ columns_changed_idle (GladeEditorProperty * eprop)
   property = glade_editor_property_get_property (eprop);
 
   glade_property_get (property, &columns);
-  g_assert (columns);
+
+  /* This can happen when the user performs DnD and there
+   * are no columns yet */
+  if (!columns)
+    return FALSE;
+
   columns = glade_column_list_copy (columns);
 
   if (gtk_tree_model_get_iter_first
